#include <avr/io.h>
#include <avr/interrupt.h> 
#include <util/delay.h>    
#include <avr/pgmspace.h> 
#include "usbdrv.h"
#define VENDOR_RQ_SET_LED    0
#define VENDOR_RQ_GET_LIGHT  2

void out_c(uint8_t pin, uint8_t val)
{
    DDRC |= 1<<pin;
    if (val)
        PORTC |= 1<<pin;
    else
        PORTC &= ~(1<<pin);
}

void out_Node(uint8_t chip, uint8_t bit)
{
    DDRB |= 1<<chip;
    if (bit)
        PORTB |= 1<<chip;
    else
        PORTB &= ~(1<<chip);
}            


uint16_t read_adc(uint8_t channel)
{
    ADMUX = 0x40;
    ADMUX |= channel;
    ADCSRA = 0xC6;
    while ((ADCSRA & (1<<ADSC)))
        ;
    return ADCL + ADCH*256;
}
usbMsgLen_t usbFunctionSetup(uchar data[8])
{
    usbRequest_t *rq = (void *)data;
    static uchar dataBuffer[2];

    if (rq->bRequest == VENDOR_RQ_SET_LED)
    {
        uint8_t led_no  = rq->wValue.bytes[0];
        uint8_t led_val = rq->wValue.bytes[1];
        out_c(led_no, led_val);
        return 0;
    }

    else if (rq->bRequest == VENDOR_RQ_GET_LIGHT)
    {   
        out_Node(0,1);
        dataBuffer[0] = read_adc(4)/256;
        dataBuffer[1] = read_adc(4)%256;
	usbMsgPtr = dataBuffer;
        return 2;
    }
    return 0;
}

int main()
{
    DDRB   = 0b00000001;
    DDRC   = 0b00000001;
    PORTC  = 0b00000000;
    PORTD  = 0b00000000;

    usbInit();
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();
    sei();
    for(;;){
        usbPoll();
    }
    return 0;
}
